from django.conf import settings
from django.core import management
from django.core.management.base import BaseCommand

from fabric.api import local

from optparse import make_option


class Command(BaseCommand):
    help = "Redeploy the current instance"

    option_list = BaseCommand.option_list + (
        make_option('--servername', action='store', type='string',
                    dest='servername', default='staging',
                    help='Server name - to pick which configuration to use'),
        make_option('--noreqs', action='store_true', dest='noreqs',
                    default=False, help='Don\'t update requirements'),
    )

    def handle(self, *args, **options):
        server_name = options.get('servername')

        noreqs = options.get('noreqs')

        if not server_name in settings.DEPLOYS:
            self.stderr.write('Non existant server config')
            return

        server = settings.DEPLOYS[server_name]

        if not noreqs:
            local('pip install -r requirements.txt')

        management.call_command('syncdb',
                interactive=False, stdout=self.stdout)
        management.call_command('migrate',
                interactive=False, stdout=self.stdout)
        management.call_command('collectstatic',
                interactive=False, stdout=self.stdout)

        # Reload the app in the webserver
        ws = server['WEBSERVER']
        if ws == 'apache':
            local('touch {0}'.format(server['WSGI_FILE']))  # reload wsgi
        elif ws == 'gunicorn':
            local('sudo kill -HUP `cat {0}`'.format(server['PID_FILE']))
        else:
            self.stderr.write('Unknown webserver type!')



from django.conf import settings
from django.core.management.base import BaseCommand

from fabric.api import run, cd, env, prefix

from optparse import make_option
import time


class Command(BaseCommand):
    help = """Redeploy the application on a remote server"""
    args = "<server_name server_name ...>"

    option_list = BaseCommand.option_list + (
        make_option('--noreqs', action='store_true', dest='reqs',
                    default=False, help='Update requirements'),
        make_option('--all', action='store_true', dest='all',
                    default=False, help='Update all instances'),
    )

    def handle(self, *args, **options):
        noreqs = options.get('reqs')
        all = options.get('all')

        if not args and not all:
            self.stderr.write('No servers selected\n')
            return

        if all:
            servers = settings.DEPLOYS
        else:
            servers = dict([(k, v) for k, v in settings.DEPLOYS.items()
                                   if k in args])

        not_found = set(args) - set(servers.keys())

        for n in not_found:
            self.stderr.write('Error - server {0} not found\n'.format(n))

        for name, server in servers.items():
            self.deploy(server, name, noreqs)

    def deploy(self, server, server_name, noreqs=False):
        starttime = time.time()
        env.host_string = '{0}@{1}'.format(server['USER'], server['HOST'])
        self.stdout.write('Depoloying to "{0}"...\n'.format(server_name))

        cmd = ('python manage.py deploy_local --servername={servername} ' +
               '{noreqs} --settings={settings}'). \
               format(noreqs='--noreqs' if noreqs else '',
                      settings=server['SETTINGS'] if 'SETTINGS' in server
                                                  else 'settings',
                  servername=server_name)

        with cd(server['DIR']):
            run('git pull origin {0}'.format(server['BRANCH']))

            with prefix('workon {0}'.format(server['ENV'])):
                run(cmd)

        self.stdout.write('Deployed successfully\n')
        self.stdout.write('Time elapsed: {0} seconds\n\n'.\
                format(time.time() - starttime))



from setuptools import setup, find_packages

setup(
    name='django-sitepush',
    author='Yuri Prezument',
    author_email='y@yprez.com',
    version='0.1dev2',
    packages=find_packages(),
    license='ISC',
    url='http://github.com/yprez/django-sitepush',
    description='Redeploy Django projects using management commands',
    long_description=open('README.rst').read(),
    install_requires=[
        'Django >= 1.3',
        'fabric >= 1.3.3',
    ],
    classifiers=(
        'Development Status :: 2 - Pre-Alpha',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: ISC License (ISCL)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ),
)
